@@ -24,7 +24,7 @@
  * 
  */
 
-static const char cvs_ident[] = "$Id: pixmap.c,v 1.60 1999/04/19 19:21:27 mej Exp $";
+static const char cvs_ident[] = "$Id: pixmap.c,v 1.1.1.1.2.5 1999/11/02 16:34:36 mej Exp $";
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -106,20 +106,24 @@ pixmap_t bgPixmap =
 # ifdef PIXMAP_SCROLLBAR
 pixmap_t upPixmap =
 {0, 0, 50, 50, None};
+pixmap_t up_clkPixmap =
+{0, 0, 50, 50, None};
 pixmap_t dnPixmap =
 {0, 0, 50, 50, None};
+pixmap_t dn_clkPixmap =
+{0, 0, 50, 50, None};
 pixmap_t sbPixmap =
 {0, 0, 50, 50, None};
 pixmap_t saPixmap =
 {0, 0, 50, 50, None};
-
+pixmap_t sa_clkPixmap =
+{0, 0, 50, 50, None};
 # endif
 
 # ifdef USE_IMLIB
 ImlibData *imlib_id = NULL;
 imlib_t imlib_bg =
 {NULL, 0, 0};
-
 #  ifdef PIXMAP_SCROLLBAR
 imlib_t imlib_up =
 {NULL, 0, 0};
@@ -129,7 +133,8 @@ imlib_t imlib_sb =
 {NULL, 0, 0};
 imlib_t imlib_sa =
 {NULL, 0, 0};
-
+imlib_t imlib_saclk =
+{NULL, 0, 0};
 #  endif
 
 #  ifdef PIXMAP_MENUBAR
@@ -138,18 +143,16 @@ pixmap_t mbPixmap =
 {0, 0, 50, 50, None};
 pixmap_t mb_selPixmap =
 {0, 0, 50, 50, None};
-
-#   ifdef USE_IMLIB
 imlib_t imlib_mb =
 {NULL, 0, 0};
 imlib_t imlib_ms =
 {NULL, 0, 0};
-
-#   endif
 #  endif
 
+inline ImlibImage *ReadImageViaImlib(const char *);
+
 inline ImlibImage *
-ReadImageViaImlib(Display * d, const char *filename)
+ReadImageViaImlib(const char *filename)
 {
   Image *tmp;
 
@@ -202,7 +205,7 @@ scale_pixmap(const char *geom, pixmap_t * pmap)
     return 0;
   scr = ScreenOfDisplay(Xdisplay, Xscreen);
   if (!scr)
-    return;
+    return 0;
 
   D_PIXMAP(("scale_pixmap(\"%s\")\n", geom));
   if (!strcmp(geom, "?")) {
@@ -451,7 +454,7 @@ render_pixmap(Window win, imlib_t image, pixmap_t pmap, int which, renderop_t re
 #else
 	pixmap = desktop_pixmap;
 	XGetGeometry(Xdisplay, desktop_pixmap, &w, &px, &py, &pw, &ph, &pb, &pd);
-	if (pw < scr->width || ph < scr->height) {
+	if (pw < (unsigned int) scr->width || ph < (unsigned int) scr->height) {
 	  desktop_pixmap = XCreatePixmap(Xdisplay, win, pw, ph, Xdepth);
 	  XCopyArea(Xdisplay, pixmap, desktop_pixmap, gc, 0, 0, pw, ph, 0, 0);
 	  colormod_trans(desktop_pixmap, gc, pw, ph);
@@ -465,7 +468,7 @@ render_pixmap(Window win, imlib_t image, pixmap_t pmap, int which, renderop_t re
     }
     if (desktop_pixmap != None) {
       XTranslateCoordinates(Xdisplay, win, desktop_window, 0, 0, &x, &y, &w);
-      if (width != last_width || height != last_height || x != last_x || y != last_y) {
+      if (width != last_width || height != last_height || (unsigned int) x != last_x || (unsigned int) y != last_y) {
 	if (TermWin.pixmap != None) {
 	  XFreePixmap(Xdisplay, TermWin.pixmap);
 	}
@@ -473,7 +476,15 @@ render_pixmap(Window win, imlib_t image, pixmap_t pmap, int which, renderop_t re
 	D_PIXMAP(("desktop_pixmap == %08x, TermWin.pixmap == %08x\n", desktop_pixmap, TermWin.pixmap));
 	if (TermWin.pixmap != None) {
 	  XGetGeometry(Xdisplay, desktop_pixmap, &w, &px, &py, &pw, &ph, &pb, &pd);
-	  if (pw < scr->width || ph < scr->height) {
+          if ((pw <= 0) || (ph <= 0)) {
+            print_error("Value of desktop pixmap property is invalid.  Please restart your "
+                        "window manager or use Esetroot to set a new one.");
+            desktop_pixmap = None;
+            XFreePixmap(Xdisplay, TermWin.pixmap);
+            TermWin.pixmap = None;
+            D_PIXMAP(("Setting background of window 0x%08x to the background color\n", win));
+            XSetWindowBackground(Xdisplay, win, PixColors[bgColor]);
+          } else if (pw < (unsigned int) scr->width || ph < (unsigned int) scr->height) {
 	    XFreeGC(Xdisplay, gc);
 	    gc = XCreateGC(Xdisplay, desktop_pixmap, 0, &gcvalue);
 	    XSetTile(Xdisplay, gc, desktop_pixmap);
@@ -511,12 +522,9 @@ render_pixmap(Window win, imlib_t image, pixmap_t pmap, int which, renderop_t re
 	XSetTSOrigin(Xdisplay, gc, pw - (scr_x % pw), ph - (scr_y % ph));
 	XSetFillStyle(Xdisplay, gc, FillTiled);
 	XFillRectangle(Xdisplay, sbPixmap.pixmap, gc, 0, 0, scr_w, scr_h);
-
-	D_PIXMAP(("XSetWindowBackgroundPixmap(sbPixmap.pixmap)\n"));
       }
       XSetWindowBackgroundPixmap(Xdisplay, scrollBar.win, sbPixmap.pixmap);
-      D_PIXMAP(("XFreePixmap(sbPixmap.pixmap)\n"));
-      /*XFreePixmap(Xdisplay, sbPixmap.pixmap); */
+      XFreePixmap(Xdisplay, sbPixmap.pixmap);
       XClearWindow(Xdisplay, scrollBar.win);
     }
 #   endif			/* PIXMAP_SCROLLBAR */
@@ -542,7 +550,7 @@ render_pixmap(Window win, imlib_t image, pixmap_t pmap, int which, renderop_t re
       /* Don't tile too big or scale too small */
       if (w > scr->width || h > scr->height) {
 	w = 1;			/* scale to 100% */
-      } else if (width > (10 * xsize) || height > (10 * ysize)) {
+      } else if (width > (unsigned int) (10 * xsize) || height > (unsigned int) (10 * ysize)) {
 	w = 0;			/* tile */
       }
 #  ifdef PIXMAP_OFFSET
@@ -552,18 +560,18 @@ render_pixmap(Window win, imlib_t image, pixmap_t pmap, int which, renderop_t re
 	if (viewport_pixmap == None) {
 	  if (w) {
 	    D_PIXMAP(("Scaling image to %dx%d\n", scr->width, scr->height));
-	    colormod_pixmap(image, gc, scr->width, scr->height);
+	    colormod_pixmap(image);
 	    Imlib_render(imlib_id, image.im, scr->width, scr->height);
 	  } else {
 	    D_PIXMAP(("Tiling image at %dx%d\n", xsize, ysize));
-	    colormod_pixmap(image, gc, xsize, ysize);
+	    colormod_pixmap(image);
 	    Imlib_render(imlib_id, image.im, xsize, ysize);
 	  }
 	  viewport_pixmap = Imlib_copy_image(imlib_id, image.im);
 	}
 	if (TermWin.pixmap != None) {
 	  XGetGeometry(Xdisplay, TermWin.pixmap, &dummy, &px, &py, &pw, &ph, &pb, &pd);
-	  if (pw != TermWin_TotalWidth() || ph != TermWin_TotalHeight()) {
+	  if (pw != (unsigned int) TermWin_TotalWidth() || ph != (unsigned int) TermWin_TotalHeight()) {
 	    XFreePixmap(Xdisplay, TermWin.pixmap);
 	    TermWin.pixmap = None;
 	  }
@@ -606,7 +614,7 @@ render_pixmap(Window win, imlib_t image, pixmap_t pmap, int which, renderop_t re
 
 	  D_PIXMAP(("render_pixmap(): no horizontal scaling\n"));
 
-	  if (xsize <= width) {
+	  if ((unsigned int) xsize <= width) {
 	    w = xsize;
 	    x = (width - w) / 2;
 	    w += x;
@@ -674,7 +682,7 @@ render_pixmap(Window win, imlib_t image, pixmap_t pmap, int which, renderop_t re
 
 	  D_PIXMAP(("render_pixmap(): no vertical scaling\n"));
 
-	  if (ysize <= height) {
+	  if ((unsigned int) ysize <= height) {
 	    h = ysize;
 	    y = (height - h) / 2;
 	    h += y;
@@ -731,7 +739,7 @@ render_pixmap(Window win, imlib_t image, pixmap_t pmap, int which, renderop_t re
 	image.last_h = h;
 
 	D_IMLIB(("ImlibRender(0x%x@%dx%d)\n", image.im, w, h));
-	colormod_pixmap(image, gc, w, h);
+	colormod_pixmap(image);
 	ImlibRender(imlib_id, image.im, w, h);
 
 	D_IMLIB(("pmap.pixmap = ImlibCopyImageToPixmap(0x%x)\n", image.im));
@@ -745,7 +753,7 @@ render_pixmap(Window win, imlib_t image, pixmap_t pmap, int which, renderop_t re
 
 	if (!((Options & Opt_pixmapTrans) && rendered)) {
 	  D_IMLIB(("ImlibRender(0x%x@%dx%d)\n", image.im, xsize, ysize));
-	  colormod_pixmap(image, gc, xsize, ysize);
+	  colormod_pixmap(image);
 	  ImlibRender(imlib_id, image.im, xsize, ysize);
 	  rendered = 1;
 	}
@@ -764,16 +772,16 @@ render_pixmap(Window win, imlib_t image, pixmap_t pmap, int which, renderop_t re
 	  pmap.pixmap = XCreatePixmap(Xdisplay, win,
 				      width, height, Xdepth);
 
-	  for (y = 0; y < height; y += ysize) {
+	  for (y = 0; (unsigned int) y < height; y += ysize) {
 	    unsigned int h = (height - y);
 
-	    if (h > ysize)
+	    if (h > (unsigned int) ysize)
 	      h = ysize;
 
-	    for (x = 0; x < width; x += xsize) {
+	    for (x = 0; (unsigned int) x < width; x += xsize) {
 	      unsigned int w = (width - x);
 
-	      if (w > xsize)
+	      if (w > (unsigned int) xsize)
 		w = xsize;
 	      D_PIXMAP(("XCopyArea(pixmap(%dx%d)->pmap.pixmap)\n", w, h));
 	      XCopyArea(Xdisplay, pixmap, pmap.pixmap, gc, 0, 0, w, h, x, y);
@@ -976,7 +984,7 @@ set_bgPixmap(const char *file)
 	imlib_bg.im = NULL;
       }
       D_IMLIB(("ReadImageViaImlib(%s)\n", (char *) f));
-      imlib_bg.im = ReadImageViaImlib(Xdisplay, (char *) f);
+      imlib_bg.im = ReadImageViaImlib((char *) f);
     }
     if (imlib_bg.im == NULL) {
 #  endif
@@ -1101,7 +1109,7 @@ set_Pixmap(const char *file, Pixmap dest_pmap, int type)
 #   ifdef USE_IMLIB
     if (f != NULL) {
       D_IMLIB(("ReadImageViaImlib(%s)\n", (char *) f));
-      img.im = ReadImageViaImlib(Xdisplay, (char *) f);
+      img.im = ReadImageViaImlib((char *) f);
     }
     if (img.im == NULL) {
 #   endif
@@ -1146,11 +1154,13 @@ set_Pixmap(const char *file, Pixmap dest_pmap, int type)
     }
   }
   D_PIXMAP(("set_scrPixmap() exitting\n"));
+  return;
+  dest_pmap = (Pixmap) 0;
 }
 #  endif			/* PIXMAP_SCROLLBAR */
 
 void
-colormod_pixmap(imlib_t image, GC gc, int w, int h)
+colormod_pixmap(imlib_t image)
 {
 
   unsigned int bright;
@@ -1238,9 +1248,9 @@ colormod_trans(Pixmap p, GC gc, int w, int h)
 
   XImage *ximg;
   register unsigned long v, i;
-  unsigned long x, y;
+  int x, y;
   unsigned int r, g, b;
-  float rm, gm, bm, shade;
+  unsigned short rm, gm, bm, shade;
   ImlibColor ctab[256];
   int real_depth = 0;
   register int br, bg, bb;
@@ -1253,12 +1263,12 @@ colormod_trans(Pixmap p, GC gc, int w, int h)
 
     XColor cols[256];
 
-    for (i = 0; i < (1 << Xdepth); i++) {
+    for (i = 0; i < (unsigned int) (1 << Xdepth); i++) {
       cols[i].pixel = i;
       cols[i].flags = DoRed | DoGreen | DoBlue;
     }
     XQueryColors(Xdisplay, Xcmap, cols, 1 << Xdepth);
-    for (i = 0; i < (1 << Xdepth); i++) {
+    for (i = 0; i < (unsigned int) (1 << Xdepth); i++) {
       ctab[i].r = cols[i].red >> 8;
       ctab[i].g = cols[i].green >> 8;
       ctab[i].b = cols[i].blue >> 8;
@@ -1276,10 +1286,10 @@ colormod_trans(Pixmap p, GC gc, int w, int h)
   if (!real_depth) {
     real_depth = Xdepth;
   }
-  shade = (float) (100 - rs_shadePct) / 100.0;
-  rm = (float) ((rs_tintMask & 0xff0000) >> 16) / 255.0 * shade;
-  gm = (float) ((rs_tintMask & 0x00ff00) >> 8) / 255.0 * shade;
-  bm = (float) (rs_tintMask & 0x0000ff) / 255.0 * shade;
+  shade = (unsigned short) ((100 - rs_shadePct) * 256) / 100;
+  rm = (unsigned short) (((rs_tintMask & 0xff0000) >> 16) * shade) / 255;
+  gm = (unsigned short) (((rs_tintMask & 0x00ff00) >> 8) * shade) / 255;
+  bm = (unsigned short) ((rs_tintMask & 0x0000ff) * shade) / 255;
 
   ximg = XGetImage(Xdisplay, p, 0, 0, w, h, -1, ZPixmap);
   if (ximg == NULL) {
@@ -1328,9 +1338,9 @@ colormod_trans(Pixmap p, GC gc, int w, int h)
     for (y = 0; y < h; y++) {
       for (x = 0; x < w; x++) {
 	v = XGetPixel(ximg, x, y);
-	r = (int) (((v >> br) & mr) * rm) & 0xff;
-	g = (int) (((v >> bg) & mg) * gm) & 0xff;
-	b = (int) (((v << bb) & mb) * bm) & 0xff;
+	r = ((((v >> br) & mr) * rm) >> 8) & 0xff;
+	g = ((((v >> bg) & mg) * gm) >> 8) & 0xff;
+	b = ((((v << bb) & mb) * bm) >> 8) & 0xff;
 	v = ((r & mr) << br) | ((g & mg) << bg) | ((b & mb) >> bb);
 	XPutPixel(ximg, x, y, v);
       }
@@ -1352,7 +1362,6 @@ get_desktop_window(void)
   unsigned char *data;
   unsigned int nchildren;
   Window w, root, *children, parent;
-  Window last_desktop_window = desktop_window;
 
   if ((prop = XInternAtom(Xdisplay, "_XROOTPMAP_ID", True)) == None) {
     D_PIXMAP(("No _XROOTPMAP_ID found.\n"));
@@ -1428,8 +1437,6 @@ get_desktop_pixmap(void)
   int format;
   unsigned long length, after;
   unsigned char *data;
-  register unsigned long i = 0;
-  time_t blah;
 
   if (desktop_window == None)
     return None;
@@ -1542,20 +1549,28 @@ set_icon_pixmap(char *filename, XWMHints * pwm_hints)
 
     if (icon_path != NULL) {
       XIconSize *icon_sizes;
-      int count, i, w = 64, h = 64;
+      int count, i, w = 8, h = 8;  /* At least 8x8 */
 
-      temp_im = ReadImageViaImlib(Xdisplay, icon_path);
+      temp_im = Imlib_load_image(imlib_id, (char *) icon_path);
       /* If we're going to render the image anyway, might as well be nice and give it to the WM in a size it likes. */
       if (XGetIconSizes(Xdisplay, Xroot, &icon_sizes, &count)) {
 	for (i = 0; i < count; i++) {
 	  D_PIXMAP(("Got icon sizes:  Width %d to %d +/- %d, Height %d to %d +/- %d\n", icon_sizes[i].min_width, icon_sizes[i].max_width,
 		    icon_sizes[i].width_inc, icon_sizes[i].min_height, icon_sizes[i].max_height, icon_sizes[i].height_inc));
-	  w = MIN(icon_sizes[i].max_width, 64);		/* 64x64 is plenty big */
-	  h = MIN(icon_sizes[i].max_height, 64);
+          if (icon_sizes[i].max_width > 64 || icon_sizes[i].max_height > 64) {
+            continue;
+          }
+          /* Find the largest supported size <= 64 */
+	  w = MAX(icon_sizes[i].max_width, w);
+	  h = MAX(icon_sizes[i].max_height, h);
 	}
 	fflush(stdout);
 	XFree(icon_sizes);
+      } else {
+        w = h = 48;
       }
+      MIN_IT(w, 64);
+      MIN_IT(h, 64);
       Imlib_render(imlib_id, temp_im, w, h);
       wm_hints->icon_pixmap = Imlib_copy_image(imlib_id, temp_im);
       wm_hints->icon_mask = Imlib_copy_mask(imlib_id, temp_im);
@@ -1605,6 +1620,7 @@ fade_in(Pixmap * pmap, ImlibImage * img, int frames)
   }
   /* how many frames to go */
   return (f - i);
+  pmap = (Pixmap *) NULL;
 }
 #   endif			/* USE_EFFECTS */
 
