@@ -3,9 +3,16 @@
  *
  */
 
-static const char cvs_ident[] = "$Id: screen.c,v 1.23 1999/04/20 21:08:54 mej Exp $";
+static const char cvs_ident[] = "$Id: screen.c,v 1.1.1.1.2.4 1999/11/02 16:34:36 mej Exp $";
+
+#include "config.h"
+#include "feature.h"
 
 /* includes */
+#include "../libmej/debug.h"
+#include "../libmej/mem.h"
+#include "../libmej/strings.h"
+#include "debug.h"
 #include "main.h"
 #ifdef USE_ACTIVE_TAGS
 # include "activetags.h"
@@ -185,7 +192,7 @@ blank_line(text_t * et, rend_t * er, int width, rend_t efs)
   register int i = width;
   rend_t *r = er, fs = efs;
 
-  memset(et, ' ', i);
+  MEMSET(et, ' ', (unsigned int) i);
   for (; i--;)
     *r++ = fs;
 }
@@ -462,7 +469,7 @@ scr_poweron(void)
 
   last_col = TermWin.ncol - 1;
 
-  memset(charsets, 'B', sizeof(charsets));
+  MEMSET(charsets, 'B', sizeof(charsets));
   rvideo = 0;
   scr_rendition(0, ~RS_None);
 #if NSCREENS
@@ -1443,7 +1450,7 @@ void
 scr_set_tab(int mode)
 {
   if (mode < 0)
-    memset(tabs, 0, TermWin.ncol * sizeof(char));
+    MEMSET(tabs, 0, TermWin.ncol * sizeof(char));
 
   else if (screen.col < TermWin.ncol)
     tabs[screen.col] = (mode ? 1 : 0);
@@ -1565,6 +1572,10 @@ eucj2jis(unsigned char *str, int len)
 
   for (i = 0; i < len; i++)
     str[i] &= 0x7F;
+#else
+  return;
+  str = (unsigned char *) NULL;
+  len = 0;
 #endif
 }
 
@@ -1590,6 +1601,10 @@ sjis2jis(unsigned char *str, int len)
       *low -= 0x1F;
     }
   }
+#else
+  return;
+  str = (unsigned char *) NULL;
+  len = 0;
 #endif
 }
 
@@ -1607,6 +1622,9 @@ set_kanji_encoding(const char *str)
       kanji_decode = eucj2jis;
     }
   }
+#else
+  return;
+  str = "";
 #endif /* KANJI */
 }
 
@@ -1719,16 +1737,6 @@ scr_expose(int x, int y, int width, int height)
       drawn_rend[i][part_end.col] = RS_Dirty;
 }
 
-/* ------------------------------------------------------------------------- */
-/*
- * Refresh the entire screen
- */
-inline void
-scr_touch(void)
-{
-  scr_expose(0, 0, TermWin.width, TermWin.height);
-}
-
 /* ------------------------------------------------------------------------- */
 /*
  * Move the display so that the line represented by scrollbar value Y is at
@@ -1815,7 +1823,6 @@ scr_printscreen(int fullhist)
 #ifdef PRINTPIPE
   int i, r, nrows, row_offset;
   text_t *t;
-  char title[256];
   FILE *fd;
 
   if ((fd = popen_printer()) == NULL)
@@ -2078,7 +2085,7 @@ scr_refresh(int type)
 #endif
 	  /* single stepping - `normal' mode */
 	  for (; ++col < ncols - 1;) {
-	    if (rend != srp[col])
+	    if ((unsigned int) rend != srp[col])
 	      break;
 	    if ((stp[col] == dtp[col]) && (srp[col] == drp[col]))
 	      break;
@@ -2626,7 +2633,7 @@ selection_make(Time tm)
     col = 0;
     if (screen.text[row][TermWin.ncol] != WRAP_CHAR) {
       if (!(Options & Opt_select_trailing_spaces)) {
-	for (; isspace(*--str););
+	for (str--; *str == ' ' || *str == '\t'; str--);
 	str++;
       }
       *str++ = '\n';
@@ -2645,6 +2652,10 @@ selection_make(Time tm)
   MIN_IT(end_col, TermWin.ncol);
   for (; col < end_col; col++)
     *str++ = *t++;
+  if (!(Options & Opt_select_trailing_spaces)) {
+    for (str--; *str == ' ' || *str == '\t'; str--);
+    str++;
+  }
   if (i)
     *str++ = '\n';
   *str = '\0';
@@ -3233,7 +3244,8 @@ mouse_report(XButtonEvent * ev)
 void
 mouse_tracking(int report, int x, int y, int firstrow, int lastrow)
 {
-/* TODO */
+  return;
+  report = x = y = firstrow = lastrow = 0;
 }
 /* ------------------------------------------------------------------------- *
  *                              DEBUG ROUTINES                               * 
@@ -3241,7 +3253,9 @@ mouse_tracking(int report, int x, int y, int firstrow, int lastrow)
 void
 debug_PasteIt(unsigned char *data, int nitems)
 {
-/* TODO */
+  return;
+  data = (unsigned char *) NULL;
+  nitems = 0;
 }
 
 /* ------------------------------------------------------------------------- */
